@@ -3,6 +3,7 @@ mod builders;
 mod bvh;
 mod bvh_node;
 mod iter;
+mod iter_indices;
 mod mbvh_node;
 mod morton;
 mod ray;
@@ -13,6 +14,7 @@ pub use aabb::*;
 pub use builders::*;
 pub use bvh_node::*;
 pub use iter::*;
+pub use iter_indices::*;
 pub use mbvh_node::*;
 pub use morton::*;
 pub use ray::*;
@@ -190,10 +192,13 @@ mod tests {
     }
 
     pub(crate) fn load_teapot() -> (Vec<Aabb<i32>>, Vec<Triangle>) {
-        use std::path::PathBuf;
         let loader = l3d::LoadInstance::new().with_default();
         let result = loader.load(LoadOptions {
-            path: PathBuf::from("objects").join("teapot.obj"),
+            source: LoadSource::String {
+                basedir: "",
+                extension: "obj",
+                source: include_str!("../objects/teapot.obj").as_bytes(),
+            },
             ..Default::default()
         });
 
